==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nodes/node/table/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionResubmitNodesNodeTableFlowWriteActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nodes.node.table.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionResubmitGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-resubmit-nodes-node-table-flow-write-actions-case {
 *   uses nx-action-resubmit-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nodes/node/(urn:opendaylight:flow:inventory?revision=2013-08-19)table/flow/instructions/instruction/instruction/write-actions-case/write-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-resubmit-nodes-node-table-flow-write-actions-case</i>
 *
 */
public interface NxActionResubmitNodesNodeTableFlowWriteActionsCase
    extends
    DataObject,
    Augmentable<NxActionResubmitNodesNodeTableFlowWriteActionsCase>,
    NxActionResubmitGrouping,
    Action
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-resubmit-nodes-node-table-flow-write-actions-case");


}

==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nodes/node/table/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionResubmitNodesNodeTableFlowWriteActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nodes.node.table.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionResubmitGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-resubmit-nodes-node-table-flow-write-actions-case {
 *   uses nx-action-resubmit-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nodes/node/(urn:opendaylight:flow:inventory?revision=2013-08-19)table/flow/instructions/instruction/instruction/write-actions-case/write-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-resubmit-nodes-node-table-flow-write-actions-case</i>
 *
 */
public interface NxActionResubmitNodesNodeTableFlowWriteActionsCase
    extends
    DataObject,
    Augmentable<NxActionResubmitNodesNodeTableFlowWriteActionsCase>,
    NxActionResubmitGrouping,
    Action
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-resubmit-nodes-node-table-flow-write-actions-case");


}
